from django.contrib import admin
from djangorestfilemanager.models import File


class FileAdmin(admin.ModelAdmin):
    search_fields = ['uuid', 'name', 'user_name', 'creation_date', 'last_mod_date']
    list_display = ['uuid', 'name', 'user_name', 'creation_date', 'last_mod_date', 'origin', 'type', 'permission',
                    'share']
    list_display_links = ['uuid', ]
    ordering = ['uuid', 'name', 'user_name', 'creation_date', 'last_mod_date', 'origin', 'type', 'permission',
                'share']
    list_filter = ['origin', 'type', 'share']


admin.site.register(File, FileAdmin)



from djangorestfilemanager.models import File
from rest_framework import serializers
import logging

logger = logging.getLogger(__name__)


class FileSerializer(serializers.ModelSerializer):

    class Meta:
        model = File
        fields = (
            'url', 'uuid', 'file', 'name', 'username', 'creation_date', 'last_mod_date', 'permission', 'type',
            'origin', 'share'
        )
        read_only_fields = ('uuid', 'name', 'username', 'creation_date', 'last_mod_date')


class FileViewSerializer(serializers.ModelSerializer):

    class Meta:
        model = File
        fields = ('uuid',)
        read_only_fields = ('uuid',)
